Module error

Module error 

Enums

TopiaryConfigError
TopiaryConfigFetchingError
Topiary can fetch an compile grammars, doing so may create errors. Usually, this error would be part of the TopiaryConfigError, however, that enum also includes nickel_lang_core::error::Error, which does not implement Sync/Send. Since fetching an compilation is something that can easily be parallelized, we create a special error that DOES implement Sync/Send.

Type Aliases

TopiaryConfigResult