pub struct GitSource {
pub git: String,
pub rev: String,
pub subdir: Option<String>,
}Fields
git: StringThe URL of the git repository that contains the tree-sitter grammar.
rev: StringThe revision of the git repository to use.
subdir: Option<String>The sub-directory within the repository where the grammar is located. Defaults to the root of the repository
Implementations