pub struct Language {
pub name: String,
pub config: LanguageConfiguration,
}Expand description
Language definitions, as far as the CLI and configuration are concerned, contain everything needed to configure formatting for that language.
Fields
name: StringThe name of the language, used as a key when looking up information in the deserialised configuration and to convert to the respective Tree-sitter grammar
config: LanguageConfigurationThe configuration of the language, includes all properties that Topiary needs to properly format the language
Implementations
Sourceimpl Language
impl Language
pub fn new(name: String, config: LanguageConfiguration) -> Self
pub fn indent(&self) -> Option<String>
pub fn find_query_file(&self) -> TopiaryConfigResult<PathBuf>
pub fn library_path(&self) -> Result<PathBuf>
pub fn grammar(&self) -> Result<Language, TopiaryConfigFetchingError>