pub struct LanguageConfiguration {
pub extensions: HashSet<String>,
pub indent: Option<String>,
pub grammar: Grammar,
}Fields
extensions: HashSet<String>A set of the filetype extensions associated with this language. This enables Topiary to switch to the right language based on the input filename.
indent: Option<String>The indentation string used for this language; defaults to “ “ (i.e., two spaces). Any string can be provided, but in most instances it will be some whitespace (e.g., “ “, “\t”, etc.)
grammar: GrammarThe tree-sitter source of the language, contains all that is needed to pull and compile the tree-sitter grammar