pub enum Source {
Builtin,
Directory(PathBuf),
File(PathBuf),
}Expand description
Sources of Nickel configuration
Variants
Implementations
Sourceimpl Source
impl Source
Sourcepub fn config_sources(
path: &Option<PathBuf>,
) -> impl Iterator<Item = (&'static str, Self)>
pub fn config_sources( path: &Option<PathBuf>, ) -> impl Iterator<Item = (&'static str, Self)>
Iterate through valid sources of configuration, in priority order (highest to lowest):
path, passed as a CLI argument/environment variable.topiary/languages.ncl(or equivalent)~/.config/topiary/languages.ncl- OS configuration directory (if different from #3)
- Built-in configuration:
Self::builtin_nickel
Sourcepub fn queries_dir(&self) -> Option<PathBuf>
pub fn queries_dir(&self) -> Option<PathBuf>
Return expected query directory associated with the source path
pub fn languages_file(&self) -> Option<PathBuf>
Sourcepub fn fetch_all(file: &Option<PathBuf>) -> Vec<Self>
pub fn fetch_all(file: &Option<PathBuf>) -> Vec<Self>
Return all valid configuration sources.
See Self::config_sources.
Sourcepub fn languages_exists(&self) -> bool
pub fn languages_exists(&self) -> bool
Checks if a given Self variant can be found as a path or value
Sourcepub fn fetch_one(file: &Option<PathBuf>) -> Self
pub fn fetch_one(file: &Option<PathBuf>) -> Self
Return a valid source of configuration with the highest priority.
See Self::config_sources.
pub fn read(&self) -> TopiaryConfigResult<Vec<u8>>